@@ -1,6 +1,6 @@
 package Test::WWW::Selenium;
 {
-  $Test::WWW::Selenium::VERSION = '1.33';
+  $Test::WWW::Selenium::VERSION = '1.34';
 }
 # ABSTRACT: Test applications using Selenium Remote Control
 use strict;
@@ -147,6 +147,17 @@ sub error_callback {
     return $self->{error_callback};
 }
 
+
+sub debug {
+    my $self = shift;
+    require Devel::REPL;
+    my $repl = Devel::REPL->new(prompt => 'Selenium$ ');
+    $repl->load_plugin($_) for qw/History LexEnv Colors Selenium Interrupt/;
+    $repl->selenium($self);
+    $repl->lexical_environment->do($repl->selenium_lex_env);
+    $repl->run;
+}
+
 1;
 
 
@@ -159,7 +170,7 @@ Test::WWW::Selenium - Test applications using Selenium Remote Control
 
 =head1 VERSION
 
-version 1.33
+version 1.34
 
 =head1 SYNOPSIS
 
@@ -232,6 +243,18 @@ set to undef then the callback will not be issued.
 
 =back
 
+=over 4
+
+=item $sel-E<gt>debug()
+
+Starts an interactive shell to pass commands to Selenium.
+
+Commands are run against the selenium object, so you just need to type:
+
+=item eg: click("link=edit")
+
+=back
+
 =head1 AUTHORS
 
 =over 4
